==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkRectangularButtonSource.java <==
// java wrapper for vtkRectangularButtonSource object
//

package vtk;
import vtk.*;

public class vtkRectangularButtonSource extends vtkButtonSource
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWidth_2(double id0);
  public void SetWidth(double id0)
    { SetWidth_2(id0); }

  private native double GetWidthMinValue_3();
  public double GetWidthMinValue()
    { return GetWidthMinValue_3(); }

  private native double GetWidthMaxValue_4();
  public double GetWidthMaxValue()
    { return GetWidthMaxValue_4(); }

  private native double GetWidth_5();
  public double GetWidth()
    { return GetWidth_5(); }

  private native void SetHeight_6(double id0);
  public void SetHeight(double id0)
    { SetHeight_6(id0); }

  private native double GetHeightMinValue_7();
  public double GetHeightMinValue()
    { return GetHeightMinValue_7(); }

  private native double GetHeightMaxValue_8();
  public double GetHeightMaxValue()
    { return GetHeightMaxValue_8(); }

  private native double GetHeight_9();
  public double GetHeight()
    { return GetHeight_9(); }

  private native void SetDepth_10(double id0);
  public void SetDepth(double id0)
    { SetDepth_10(id0); }

  private native double GetDepthMinValue_11();
  public double GetDepthMinValue()
    { return GetDepthMinValue_11(); }

  private native double GetDepthMaxValue_12();
  public double GetDepthMaxValue()
    { return GetDepthMaxValue_12(); }

  private native double GetDepth_13();
  public double GetDepth()
    { return GetDepth_13(); }

  private native void SetBoxRatio_14(double id0);
  public void SetBoxRatio(double id0)
    { SetBoxRatio_14(id0); }

  private native double GetBoxRatioMinValue_15();
  public double GetBoxRatioMinValue()
    { return GetBoxRatioMinValue_15(); }

  private native double GetBoxRatioMaxValue_16();
  public double GetBoxRatioMaxValue()
    { return GetBoxRatioMaxValue_16(); }

  private native double GetBoxRatio_17();
  public double GetBoxRatio()
    { return GetBoxRatio_17(); }

  private native void SetTextureRatio_18(double id0);
  public void SetTextureRatio(double id0)
    { SetTextureRatio_18(id0); }

  private native double GetTextureRatioMinValue_19();
  public double GetTextureRatioMinValue()
    { return GetTextureRatioMinValue_19(); }

  private native double GetTextureRatioMaxValue_20();
  public double GetTextureRatioMaxValue()
    { return GetTextureRatioMaxValue_20(); }

  private native double GetTextureRatio_21();
  public double GetTextureRatio()
    { return GetTextureRatio_21(); }

  private native void SetTextureHeightRatio_22(double id0);
  public void SetTextureHeightRatio(double id0)
    { SetTextureHeightRatio_22(id0); }

  private native double GetTextureHeightRatioMinValue_23();
  public double GetTextureHeightRatioMinValue()
    { return GetTextureHeightRatioMinValue_23(); }

  private native double GetTextureHeightRatioMaxValue_24();
  public double GetTextureHeightRatioMaxValue()
    { return GetTextureHeightRatioMaxValue_24(); }

  private native double GetTextureHeightRatio_25();
  public double GetTextureHeightRatio()
    { return GetTextureHeightRatio_25(); }

  private native void SetOutputPointsPrecision_26(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_26(id0); }

  private native int GetOutputPointsPrecision_27();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_27(); }

  public vtkRectangularButtonSource() { super(); }

  public vtkRectangularButtonSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkRectangularButtonSource.java <==
// java wrapper for vtkRectangularButtonSource object
//

package vtk;
import vtk.*;

public class vtkRectangularButtonSource extends vtkButtonSource
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWidth_2(double id0);
  public void SetWidth(double id0)
    { SetWidth_2(id0); }

  private native double GetWidthMinValue_3();
  public double GetWidthMinValue()
    { return GetWidthMinValue_3(); }

  private native double GetWidthMaxValue_4();
  public double GetWidthMaxValue()
    { return GetWidthMaxValue_4(); }

  private native double GetWidth_5();
  public double GetWidth()
    { return GetWidth_5(); }

  private native void SetHeight_6(double id0);
  public void SetHeight(double id0)
    { SetHeight_6(id0); }

  private native double GetHeightMinValue_7();
  public double GetHeightMinValue()
    { return GetHeightMinValue_7(); }

  private native double GetHeightMaxValue_8();
  public double GetHeightMaxValue()
    { return GetHeightMaxValue_8(); }

  private native double GetHeight_9();
  public double GetHeight()
    { return GetHeight_9(); }

  private native void SetDepth_10(double id0);
  public void SetDepth(double id0)
    { SetDepth_10(id0); }

  private native double GetDepthMinValue_11();
  public double GetDepthMinValue()
    { return GetDepthMinValue_11(); }

  private native double GetDepthMaxValue_12();
  public double GetDepthMaxValue()
    { return GetDepthMaxValue_12(); }

  private native double GetDepth_13();
  public double GetDepth()
    { return GetDepth_13(); }

  private native void SetBoxRatio_14(double id0);
  public void SetBoxRatio(double id0)
    { SetBoxRatio_14(id0); }

  private native double GetBoxRatioMinValue_15();
  public double GetBoxRatioMinValue()
    { return GetBoxRatioMinValue_15(); }

  private native double GetBoxRatioMaxValue_16();
  public double GetBoxRatioMaxValue()
    { return GetBoxRatioMaxValue_16(); }

  private native double GetBoxRatio_17();
  public double GetBoxRatio()
    { return GetBoxRatio_17(); }

  private native void SetTextureRatio_18(double id0);
  public void SetTextureRatio(double id0)
    { SetTextureRatio_18(id0); }

  private native double GetTextureRatioMinValue_19();
  public double GetTextureRatioMinValue()
    { return GetTextureRatioMinValue_19(); }

  private native double GetTextureRatioMaxValue_20();
  public double GetTextureRatioMaxValue()
    { return GetTextureRatioMaxValue_20(); }

  private native double GetTextureRatio_21();
  public double GetTextureRatio()
    { return GetTextureRatio_21(); }

  private native void SetTextureHeightRatio_22(double id0);
  public void SetTextureHeightRatio(double id0)
    { SetTextureHeightRatio_22(id0); }

  private native double GetTextureHeightRatioMinValue_23();
  public double GetTextureHeightRatioMinValue()
    { return GetTextureHeightRatioMinValue_23(); }

  private native double GetTextureHeightRatioMaxValue_24();
  public double GetTextureHeightRatioMaxValue()
    { return GetTextureHeightRatioMaxValue_24(); }

  private native double GetTextureHeightRatio_25();
  public double GetTextureHeightRatio()
    { return GetTextureHeightRatio_25(); }

  private native void SetOutputPointsPrecision_26(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_26(id0); }

  private native int GetOutputPointsPrecision_27();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_27(); }

  public vtkRectangularButtonSource() { super(); }

  public vtkRectangularButtonSource(long id) { super(id); }
  public native long   VTKInit();

}
